#!/usr/bin/env bash
# MYP Watchdog für Chromium Browser
# Empfohlene Ausführung über crontab: */5 * * * * /home/pi/watchdog.sh > /dev/null 2>&1

# Funktion zum Loggen von Nachrichten
log() {
  echo "$(date '+%Y-%m-%d %H:%M:%S') - $1" >> /home/pi/myp-watchdog.log
}

# Prüfen, ob Chromium läuft
if ! pgrep -x "chromium-browse" > /dev/null; then
  log "Chromium nicht gefunden - starte neu"
  
  # Alle eventuell noch vorhandenen Chromium-Prozesse beenden
  pkill -f chromium || true
  
  # Warten bis alle Prozesse beendet sind
  sleep 2
  
  # Kiosk-Script neu starten
  /home/pi/kiosk.sh
  
  log "Chromium neugestartet"
else
  # Optional: Nur für Debug-Zwecke
  # log "Chromium läuft normal"
  :
fi

# Prüfen, ob MYP Flask-Dienst läuft
if ! systemctl is-active --quiet myp.service; then
  log "MYP Flask-Dienst ist nicht aktiv - starte neu"
  
  # Dienst neustarten
  sudo systemctl restart myp.service
  
  log "MYP Flask-Dienst neugestartet"
fi

exit 0 